aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--ChangeLog5
-rw-r--r--test/fileutils/test_fileutils.rb4
2 files changed, 7 insertions, 2 deletions
diff --git a/ChangeLog b/ChangeLog
index 29262bfd3d..448dd8d152 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,8 @@
+Wed Jun 5 09:46:46 2013 NARUSE, Yui <naruse@ruby-lang.org>
+
+ * test/fileutils/test_fileutils.rb (TestFileUtils#test_mkdir): add
+ EACCES for Windows.
+
Wed Jun 5 08:13:37 2013 Tanaka Akira <akr@fsij.org>
* bignum.c (rb_big_pow): Don't need to multiply SIZEOF_BDIGITS.
diff --git a/test/fileutils/test_fileutils.rb b/test/fileutils/test_fileutils.rb
index f4996e5b9e..af8358bd01 100644
--- a/test/fileutils/test_fileutils.rb
+++ b/test/fileutils/test_fileutils.rb
@@ -759,8 +759,8 @@ class TestFileUtils
assert_equal 0700, (File.stat('tmp/tmp').mode & 0777) if have_file_perm?
Dir.rmdir 'tmp/tmp'
- # EISDIR on OS X, FreeBSD; EEXIST on Linux
- assert_raise(Errno::EISDIR, Errno::EEXIST) {
+ # EISDIR on OS X, FreeBSD; EEXIST on Linux; Errno::EACCES on Windows
+ assert_raise(Errno::EISDIR, Errno::EEXIST, Errno::EACCES) {
mkdir '/'
}
end